.. _reference:

Reference
*********

Charmcraft is a part of the `Juju Charm SDK <https://juju.is/docs/sdk>`_. This
documentation only contains references about Charmcraft itself. Overall SDK reference
data can be found in the `Charm SDK docs <https://juju.is/docs/sdk/reference>`_.

.. toctree::
    :maxdepth: 2

    commands
    models/index
    changelog
